@@ -18,25 +18,26 @@ import com.openexchange.admin.soap.reseller.user.soap.dataobjects.User;
  *
  * <pre>
  * &lt;complexType>
- *   &lt;complexContent>
- *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- *       &lt;sequence>
- *         &lt;element name="ctx" type="{http://dataobjects.soap.reseller.admin.openexchange.com/xsd}ResellerContext" minOccurs="0"/>
- *         &lt;element name="user" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" minOccurs="0"/>
- *         &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
- *       &lt;/sequence>
- *     &lt;/restriction>
- *   &lt;/complexContent>
+ * &lt;complexContent>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ * &lt;sequence>
+ * &lt;element name="ctx" type="{http://dataobjects.soap.reseller.admin.openexchange.com/xsd}ResellerContext" minOccurs="0"/>
+ * &lt;element name="user" type="{http://dataobjects.soap.admin.openexchange.com/xsd}User" minOccurs="0"/>
+ * &lt;element name="auth" type="{http://dataobjects.rmi.admin.openexchange.com/xsd}Credentials" minOccurs="0"/>
+ * &lt;element name="reassign" type="Integer" minOccurs="0"/>
+ * &lt;/sequence>
+ * &lt;/restriction>
+ * &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
  *
- *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "", propOrder = {
     "ctx",
     "user",
-    "auth"
+    "auth",
+    "reassign"
 })
 @XmlRootElement(name = "delete")
 public class Delete {
@@ -47,6 +48,8 @@ public class Delete {
     protected User user;
     @XmlElement(nillable = true)
     protected Credentials auth;
+    @XmlElement(nillable = true)
+    protected Integer reassign;
 
     /**
      * Ruft den Wert der ctx-Eigenschaft ab.
@@ -120,4 +123,12 @@ public class Delete {
         this.auth = value;
     }
 
+    public Integer getReassign() {
+        return reassign;
+    }
+
+    public void setReassign(Integer reassign) {
+        this.reassign = reassign;
+    }
+
 }
